@@ -2,7 +2,7 @@ import requests
 import json
 import os
 
-API_TAGO = os.environ.get('TAGO_API') or 'https://api.tago.io'
+API_TAGO = os.environ.get('TAGOIO_API') or 'https://api.tago.io'
 
 
 class Sms:
